# InsPecT: A Proteomics Search Toolkit

Copyright 2007, The Regents of the University of California
Version 20120103 documentation

### Table of Contents
- Overview
- Copyright information
- Installation
- Database
- Searching
- Analysis
- Basic Tutorial
- Advanced Tutorial
- Unrestricted Search Tutorial

  # Documentation Overview

  This is the documentation for InsPecT, a MS/MS database search tool. A general description of the program can be found here online. The documentation contains two general types of information: tutorials and docs pages. The tutorials walk through basic setup and usage of InsPecT and are highly recommended. The docs pages are more detailed documentation on options available within the program.
  InsPecT was developed at the University of California, San Diego and the project homepage is here. A Windows executable is available for download, as well as the ANSI C source code (which compiles on Windows, Linux, or Macintosh). Inspect is free for educational, research, and non-profit purposes.
  The following publications provide additional information on InsPecT; you may wish to cite them if you use InsPecT search results in your research:
- S. Tanner, H. Shu, A. Frank, L.Wang, E. Zandi, M. Mumby, P.A. Pevzner, and V. Bafna. Inspect: Fast and accurate identification of post-translationally modified peptides from tandem mass spectra. Anal. Chem., 77(14):4626–4639, 2005.
- Identification of Post-translational Modifications via Blind Search of Mass-Spectra. Dekel Tsur, Stephen Tanner, Ebrahim Zandi, Vineet Bafna, Pavel A. Pevzner. Nature Biotechnology 23, 1562-2567 (01 Dec 2005).
  The authors and principal investigator welcome questions, comments, and corrections.

  ### Bugs

  Bugs in Inspect are tracked using JIRA. If you encounter problems, please submit a bug report online!